@@ -223,7 +223,7 @@ class Experimento:
                                                 subsucesiones_aleatorias=subsucesiones_aleatorias)
         """
 
-    def realiza_procesamiento_MOTUS(self, objeto, intervalo, genera_matriz_recurrencia):
+    def realiza_procesamiento_MOTUS(self, objeto, intervalo, genera_matriz_recurrencia, genera_regiones_preferidas):
         self.calcula_distancias()
         self.calcula_distancia_promediada_con_objeto(objeto, intervalo)
         self.calcula_velocidades()
@@ -231,8 +231,10 @@ class Experimento:
         self.calcula_regiones_cuadriculadas()
         if genera_matriz_recurrencia is True:
             self.calcula_matrices_de_recurrencia()
-        if self.matriz_cuadriculada_regiones_preferidas is not None:
+        if genera_regiones_preferidas is True:
             self.genera_matriz_cuadriculada_con_regiones_preferidas()
+            self.genera_matriz_cuadriculada_solo_regiones_preferidas()
+            self.genera_matriz_cuadriculada_solo_regiones_no_preferidas()
 
     def verifica_intervalo_tiempo(self):
         arreglo_tiempo = self.tiempo
